/*******************************************************************************
 * Copyright (c) 2003, 2010 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 *******************************************************************************/

// @(#) $Id:  $
package at.spardat.xma.mdl.table;

/**
 * This interface is intended for supporting sorting in table containing only
 * part of the whole data. E.g for tables used with {@link at.spardat.xma.mdl.paging.IPagingWM}.
 * For such table, which contains only a slice or page of the whole data, sorting just
 * the slice is not really satisfying. You will not want to sort the first n data objects of the
 * result, but to show the first n data objects of the sorted result.
 * To achieve this you register an implementation of this interface to the table using
 * {@link ITableWMClient#setExternalSorter(TableExternalSorterClient)}. In the method
 * {@link #sort(int, boolean)} of your implementation, you can make an RPC in which you
 * make a new query to the database with the appropriate <code>order by</code> clause
 * and set the new slice into the database.
 * If you use a {@link at.spardat.xma.mdl.paging.IPagingWM}, you can query the sorting information
 * on server side, too. It is available as {@link at.spardat.xma.mdl.paging.IPagingWM#getSortingColumn()}
 * and {@link at.spardat.xma.mdl.paging.IPagingWM#getAscending()}
 *
 * @author gub
 * @since 2.3.0
 */
public interface TableExternalSorterClient {
    /**
     * Sort the given column. It is the responsibility of the implementor of this method,
     * to clear the table and fill it with the new rows in sorted order.
     * @param sortingColumn column to sort
     * @param ascending if true sort ascending, if false sort descending
     */
    public void sort(int sortingColumn, boolean ascending);
}
